@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 # JinjaFx - Jinja2 Templating Tool
-# Copyright (c) 2020-2022 Chris Mason <chris@netnix.org>
+# Copyright (c) 2020-2023 Chris Mason <chris@netnix.org>
 #
 # Permission to use, copy, modify, and distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -28,13 +28,13 @@ from cryptography.hazmat.primitives.ciphers.modes import CTR
 from cryptography.hazmat.backends import default_backend
 from cryptography.exceptions import InvalidSignature
 
-__version__ = '1.14.2'
+__version__ = '1.14.3'
 
 def main():
   try:
     if not any(x in ['-q', '-encrypt', '-decrypt'] for x in sys.argv):
       print(f'JinjaFx v{__version__} - Jinja2 Templating Tool')
-      print('Copyright (c) 2020-2022 Chris Mason <chris@netnix.org>\n')
+      print('Copyright (c) 2020-2023 Chris Mason <chris@netnix.org>\n')
 
     prog = os.path.basename(sys.argv[0])
     jinjafx_usage = '-t <template.j2> [-d <data.csv>] [-g <vars.yml>]\n'
@@ -588,6 +588,7 @@ class JinjaFx():
     if isinstance(template, str):
       env = jinja2env(extensions=gvars['jinja2_extensions'], **jinja2_options)
       template = env.from_string(template)
+
     else:
       env = jinja2env(extensions=gvars['jinja2_extensions'], loader=jinja2.FileSystemLoader(os.path.dirname(template.name)), **jinja2_options)
       template = env.get_template(os.path.basename(template.name))
@@ -597,9 +598,9 @@ class JinjaFx():
 
       if jinjafx_render_vars != 'no':
         gyaml = env.from_string(yaml.dump(gvars, sort_keys=False)).render(gvars)
-        env.globals.update(yaml.load(gyaml, Loader=yaml.SafeLoader))
-      else:
-        env.globals.update(gvars)
+        gvars = yaml.load(gyaml, Loader=yaml.SafeLoader)
+
+      env.globals.update(gvars)
 
     env.globals.update({ 'jinjafx': {
       'version': __version__,
